==> openshift-model-monitoring-5.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertingSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AlertingSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec,io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecBuilder>{
  public AlertingSpecBuilder() {
    this(false);
  }
  public AlertingSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new AlertingSpec(), validationEnabled);
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AlertingSpec(), validationEnabled);
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec instance) {
    this(fluent, instance, false);
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlertmanagers(instance.getAlertmanagers()); 
    this.validationEnabled = validationEnabled; 
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec instance) {
    this(instance,false);
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlertmanagers(instance.getAlertmanagers()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec build() {
    AlertingSpec buildable = new AlertingSpec(fluent.getAlertmanagers());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AlertingSpecBuilder that = (AlertingSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertingSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AlertingSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec,io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecBuilder>{
  public AlertingSpecBuilder() {
    this(false);
  }
  public AlertingSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new AlertingSpec(), validationEnabled);
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AlertingSpec(), validationEnabled);
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec instance) {
    this(fluent, instance, false);
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAlertmanagers(instance.getAlertmanagers()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec instance) {
    this(instance,false);
  }
  public AlertingSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAlertmanagers(instance.getAlertmanagers()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.AlertingSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.AlertingSpec build() {
    AlertingSpec buildable = new AlertingSpec(fluent.getAlertmanagers());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AlertingSpecBuilder that = (AlertingSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
